summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorJagannadha Sutradharudu Teki <jaganna@xilinx.com>2014-01-07 00:11:35 +0530
committerJagannadha Sutradharudu Teki <jaganna@xilinx.com>2014-01-12 21:40:22 +0530
commit056fbc73d54df64adcb93c513cba708acb2683bd (patch)
tree4243a3f6eb6f1a2fabc57cdad08031fc4e351cd6 /include
parentf77f469117ab3184ac45683a50dc446265be28cc (diff)
downloadtalos-obmc-uboot-056fbc73d54df64adcb93c513cba708acb2683bd.tar.gz
talos-obmc-uboot-056fbc73d54df64adcb93c513cba708acb2683bd.zip
sf: Add dual memories support - DUAL_PARALLEL
This patch added support for accessing dual memories in parallel connection with single chipselect line from controller. For more info - see doc/SPI/README.dual-flash Signed-off-by: Jagannadha Sutradharudu Teki <jaganna@xilinx.com>
Diffstat (limited to 'include')
-rw-r--r--include/spi.h3
-rw-r--r--include/spi_flash.h5
2 files changed, 6 insertions, 2 deletions
diff --git a/include/spi.h b/include/spi.h
index d214d82923..ffd66478b1 100644
--- a/include/spi.h
+++ b/include/spi.h
@@ -47,6 +47,7 @@
/* SPI bus connection options */
#define SPI_CONN_DUAL_SHARED 1 << 0
+#define SPI_CONN_DUAL_SEPARATED 1 << 1
/* Header byte that marks the start of the message */
#define SPI_PREAMBLE_END_BYTE 0xec
@@ -66,7 +67,7 @@
* @max_write_size: If non-zero, the maximum number of bytes which can
* be written at once, excluding command bytes.
* @memory_map: Address of read-only SPI flash access.
- * @option: Varies SPI bus options - separate bus.
+ * @option: Varies SPI bus options - separate, shared bus.
* @flags: Indication of SPI flags.
*/
struct spi_slave {
diff --git a/include/spi_flash.h b/include/spi_flash.h
index 36f1f033c0..f79f0eacca 100644
--- a/include/spi_flash.h
+++ b/include/spi_flash.h
@@ -40,6 +40,7 @@ enum spi_read_cmds {
enum spi_dual_flash {
SF_SINGLE_FLASH = 0,
SF_DUAL_STACKED_FLASH = 1 << 0,
+ SF_DUAL_PARALLEL_FLASH = 1 << 1,
};
/**
@@ -70,7 +71,8 @@ extern const struct spi_flash_params spi_flash_params_table[];
*
* @spi: SPI slave
* @name: Name of SPI flash
* @dual_flash: Indicates dual flash memories - dual stacked
* @size: Total flash size
* @page_size: Write (page) size
* @sector_size: Sector size
@@ -96,6 +98,7 @@ struct spi_flash {
struct spi_slave *spi;
const char *name;
u8 dual_flash;
+ u8 shift;
u32 size;
u32 page_size;
OpenPOWER on IntegriCloud
@@ -70,7 +71,8 @@ extern const struct spi_flash_params spi_flash_params_table[];
* @spi: SPI slave
* @name: Name of SPI flash
- * @dual_flash: Indicates dual flash memories - dual stacked
+ * @dual_flash: Indicates dual flash memories - dual stacked, parallel
+ * @shift: Flash shift useful in dual parallel
* @size: Total flash size
* @page_size: Write (page) size